@@ -15,7 +15,6 @@
 #' pln: Poisson lognormal (PLN) model \cr \cr
 #' pln_linear: recursive PLN-linear model \cr \cr
 #' pln_probit: recursive PLN-probit model \cr \cr
-#' @docType package
 #' @name endogeneity
 #' @importFrom statmod gauss.quad
 #' @importFrom stats binomial rnorm dnorm pnorm qnorm dpois dlogis plogis model.frame model.matrix model.response optim pchisq poisson runif lm glm coef sigma logLik
@@ -25,6 +24,7 @@
 #' @rawNamespace import(data.table)
 #' @importFrom Rcpp sourceCpp
 #' @useDynLib endogeneity
-#' @references Peng, Jing. (2022) Identification of Causal Mechanisms from Randomized Experiments: A Framework for Endogenous Mediation Analysis. Information Systems Research (Forthcoming), Available at https://doi.org/10.1287/isre.2022.1113
+#' @references Peng, Jing. (2023) Identification of Causal Mechanisms from Randomized Experiments: A Framework for Endogenous Mediation Analysis. Information Systems Research, 34(1):67-84. Available at https://doi.org/10.1287/isre.2022.1113
 NULL
+'_PACKAGE'
 #> NULL
\ No newline at end of file
