@@ -316,7 +316,7 @@ Gradient_probit_linearRE = function(par,y,d,x,w,group,H=20,verbose=1,variance=FA
 #' print(est$estimates, digits=3)
 #' @export
 #' @family endogeneity
-#' @references Chen, H., Peng, J., Li, H., & Shankar, R. (2022). Impact of Refund Policy on Sales of Paid Information Services: The Moderating Role of Product Characteristics. Available at SSRN: https://ssrn.com/abstract=4114972.
+#' @references Chen, H., Li, H., Peng, J., & Shankar, R. (2022). Impact of Refundability on Sales of Digital Knowledge Products: The Moderating Role of Product Characteristics. Available at SSRN: https://ssrn.com/abstract=4114972.
 probit_linearRE = function(form_probit, form_linear, id, data=NULL, par=NULL, method='BFGS', H=20, stopUpdate=F, init=c('zero', 'unif', 'norm', 'default')[4], verbose=0){
     # 1.1 Sort data by id
     if(is.null(data) && is.numeric(id)){
@@ -326,7 +326,7 @@ probit_linearRE = function(form_probit, form_linear, id, data=NULL, par=NULL, me
         ind_data = NULL
     } else if(!is.null(data) && is.character(id)){
         id_var = id
-        id = data[, id]
+        id = data[[id_var]]
         ord = order(id)
         id = id[ord]
         group = c(0,cumsum(table(as.integer(factor(id)))))
